@@ -38,12 +38,12 @@ class Tokeniser:
                     continue 
                 raw_token = ' '.join(words[index_start:index_end])
                 normalised_token = PREPROCESSOR.normalise(text=' '.join(ngram))
-                if raw_token in self.special_tokens:
-                    id = Poincare.SIZE_VOCABULARY.value + self.special_tokens.index(raw_token)
-                    vector = full(Poincare.SIZE_VECTOR.value,-1)
-                elif raw_token in VOCABULARY:
+                if raw_token in VOCABULARY:
                     id = VOCABULARY.index(raw_token)
                     vector = VECTORS[id]
+                elif raw_token in self.special_tokens:
+                    id = Poincare.SIZE_VOCABULARY.value + self.special_tokens.index(raw_token)
+                    vector = full(Poincare.SIZE_VECTOR.value,-1)
                 elif normalised_token in VOCABULARY:
                     id = VOCABULARY.index(normalised_token)
                     vector = VECTORS[id]
@@ -51,7 +51,7 @@ class Tokeniser:
                     id = len(self)-1
                     vector = zeros(Poincare.SIZE_VECTOR.value)
                     normalised_token = Poincare.UNKNOWN.value
-                if id <= Poincare.SIZE_VOCABULARY.value or ngram_size==1:
+                if id < Poincare.SIZE_VOCABULARY.value or ngram_size==1:
                     tokens[index_start:index_end] = [Poincare.SKIP.value]*ngram_size
                     tokens[index_start] = Token(
                         raw_token=raw_token,
